@@ -7,8 +7,8 @@ import mobster.utils_mobster as mut
 
 
 @config_enumerate
-def model(data, K=1, tail=1, purity=0.96, alpha_prior_concentration = 2.5, alpha_prior_rate = 5, number_of_trials_clonal_mean=500., number_of_trials_k=300.,
-         prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.]):
+def model(data, K=1, tail=1, purity=0.96, alpha_prior_concentration = 5, alpha_prior_rate = 10, number_of_trials_clonal_mean=500., number_of_trials_k=300.,
+         prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.], alpha_precision_concentration = 5, alpha_precision_rate=0.05):
 
     """Hierarchical bayesian model for Subclonal Deconvolution from VAF
 
@@ -60,16 +60,19 @@ def model(data, K=1, tail=1, purity=0.96, alpha_prior_concentration = 2.5, alpha
         counts_clones[i] = counts_clones.get(i, 0) + 1
 
     # Prior over the mean of the alphas
-    alpha_prior = pyro.sample('u', dist.Uniform(0.5, 5))
+    alpha_prior = pyro.sample('u', dist.Uniform(0.1, 5))
 
     alpha_prior_sd = pyro.sample('sd_tail', dist.Gamma(concentration=alpha_prior_concentration, rate=alpha_prior_rate))
 
     # We enter the karyotype plate
     # We may think about tensorizing it
     for kr in pyro.plate("kr", len(karyos)):
+        alpha_precision = pyro.sample('alpha_precision_{}'.format(kr), dist.Gamma(concentration=alpha_precision_concentration,
+                                                                    rate=alpha_precision_rate))
 
         # sample the tail slope
-        alpha = pyro.sample('alpha_{}'.format(kr), dist.LogNormal(torch.log(alpha_prior), alpha_prior_sd))
+        alpha_teo = pyro.sample('alpha_{}'.format(kr), dist.LogNormal(torch.log(alpha_prior * mut.theo_allele_list[karyos[kr]]), alpha_prior_sd))
+        alpha = torch.abs(alpha_teo + pyro.sample("alpha_noise_{}".format(kr), dist.Normal(torch.zeros_like(alpha_teo),1/alpha_precision)))
 
         # We construct two different computational graphs for cases with 2 and 1 clonal clusters
         if theoretical_num_clones[kr] == 2:
