@@ -54,11 +54,12 @@ def plot_results(data, inf_res, bins=50, output = "results.png",fig_height = 4,
 
         if tail == 1:
             alpha = params["tail_shape"]
+            nall = mut.theo_allele_list[kr]
             x = np.linspace(0.05, 1, 200)
-            p = pareto.pdf(x, alpha, scale=params["tail_scale"]) * assignment_probs[0]
-            ci = lognorm.ppf(np.array([0.01,0.99]), loc=np.log(alpha), s = params["tail_shape_sd"])
-            p1 = pareto.pdf(x, ci[0], scale=params["tail_scale"]) * assignment_probs[0]
-            p2 = pareto.pdf(x, ci[1], scale=params["tail_scale"]) * assignment_probs[0]
+            p = pareto.pdf(x, alpha * nall, scale=params["tail_scale"]) * assignment_probs[0]
+            ci = 2 * (1/params["tail_noise"])
+            p1 = pareto.pdf(x, np.abs(alpha - ci) * nall, scale=params["tail_scale"]) * assignment_probs[0]
+            p2 = pareto.pdf(x, np.abs(alpha + ci)  * nall, scale=params["tail_scale"]) * assignment_probs[0]
             if nKar == 1:
                 axs.plot(x, p, linewidth=1.5, color="tab:pink")
 
